@@ -348,6 +348,8 @@ class ResearchToolApi(metaclass=Singleton):
                 if col == benchmark_name:
                     continue
                 _df = price_df[[col]].join(benchmark_df.rename(columns={benchmark_name:'benchmark'})).dropna()
+                if _df.empty:
+                    continue
                 _df = _df / _df.iloc[0]
                 _df = (_df[col] / _df['benchmark']).to_frame()
                 _df.columns = [col]
@@ -453,7 +455,7 @@ class ResearchToolApi(metaclass=Singleton):
 
                 stats_dic = CalculatorBase.get_stat_result(dates=all_price.index, values=all_price[asset], risk_free_rate=0.025)
                 stats_dic['资产名'] = asset
-                stats_dic['初始权重'] = index_wgt_dic_chn.get(asset, 1)
+                stats_dic['初始权重'] = index_wgt_dic_chn.get(asset, np.sum(index_wgt))
                 res.append(stats_dic)
             port_stats = pd.DataFrame(res).set_index('资产名')[list(stats_name.keys())+['初始权重']].rename(columns=stats_name)
             round_3_list = ['年化收益','年化波动','夏普','最大回撤']
