@@ -1,4 +1,5 @@
 from pandas.tseries.offsets import DateOffset
+import numpy as np
 from ....util.config import SurfingConfigurator
 from ...api.raw import RawDataApi
 from ...api.basic import BasicDataApi
@@ -12,6 +13,7 @@ class DataChecker:
     def __init__(self):
         self.wechat_bot = WechatBot()
         self.wechat_hook = SurfingConfigurator().get_wechat_webhook_settings('wechat_webhook_data_check')
+        self.reasearch_api = ResearchApi()
 
     def get_df_leq_value_index(self, df, index_id, value):
         tds = df[df <= value][index_id].dropna().index.tolist()
@@ -428,6 +430,75 @@ class DataChecker:
         except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from DataChecker.process_fund_info')
             
+    def _future_check_pre_settlement_price(self, data):
+        # 前结算价
+        df = data.dropna(how='any')
+        df.index=df.datetime
+        df.index = pd.to_datetime(df.index)
+        cons = (df.pre_clear - df.clear.shift(1))
+        cons = cons.dropna()
+        thresh_hold = 0.11
+        if len(cons[abs(cons)>thresh_hold]) > 0:
+            df1 = df[1:].shift(1)[abs(cons)>thresh_hold]
+            df1.index=(df1.index - datetime.timedelta(days=1)).tolist()
+            cons_df = pd.concat([df1,df[1:][abs(cons)>thresh_hold]],axis=0)
+            cons_df.set_index(keys='datetime',drop=True, inplace=True)
+            cons_df = cons_df.sort_index()
+            cons_df = cons_df.dropna()
+        #             tag = {'em_id' : cons_df.em_id.values.tolist(),
+        #                    'datetime':pd.Series(cons_df.index.values).apply(lambda x:x.strftime('%Y-%m-%d')).tolist(),
+        #                    'pre_clear' : cons_df.pre_clear.values.tolist(),
+        #                    'clear' : cons_df.clear.values.tolist()}
+            tag = f'    [pre_settlement_price]  em_id : {cons_df.em_id.iloc[0]},days: {int(len(cons_df)/2)}'
+            return tag
+
+    def _future_check_average_price(self,data,multiplier):
+        # 成交均价
+        # multiplier 合约乘数
+        df = data.dropna(how='any')
+        df.index=df.datetime
+        df.index = pd.to_datetime(df.index)
+        avg = df.average_price.round(1) - (df.uni_amount/(df.uni_volume * multiplier)).round(1) 
+        df = df.copy()
+        df['average_price_par'] = (df.uni_amount/(df.uni_volume * multiplier)+np.exp(-8)).round(2)
+        thresh_hold = 0.11
+        if len(avg[abs(avg)>thresh_hold]) > 0:
+            mean_df = df[abs(avg)>thresh_hold]
+            #             tag = {'em_id' : mean_df.em_id.values.tolist(),
+            #                    'datetime': pd.Series(mean_df.index.values).apply(lambda x:x.strftime('%Y-%m-%d')).tolist(),
+            #                    'average_price' : mean_df.average_price.values.tolist(),
+            #                    'average_price_par' : mean_df.average_price_par.values.tolist()}
+            tag = f'    [average_price]  em_id : {mean_df.em_id.iloc[0]},days: {int(len(mean_df)/2)}'
+            return tag
+
+    def _future_check_spread(self,data,index_id,start_date,end_date):
+        # 价差
+        # index_id: csi500、hs300、sse50
+        df = data.dropna(how='any')
+        df.index=df.datetime
+        df.index = pd.to_datetime(df.index)
+
+        index_quote = self.reasearch_api.get_index_quote(start_date=start_date,
+                                             end_date=end_date,
+                                             index_ids=[index_id])
+        index_quote = index_quote.pivot_table(index='datetime', columns='index_id',values='close')
+
+        df1 = pd.merge(index_quote,df,left_index=True, right_index=True,how='inner')
+        # 价差 = 收盘价 - 指数价格
+        df1['spread_par'] = (df1.close - df1[index_id]).round(2)
+        spr = df1.spread_par - df1.spread.round(2)
+
+        if len(spr[abs(spr)>0.011]) > 0:
+            f_df = df1[abs(spr)>0.011]
+#             tag = {'em_id': f_df.em_id.values.tolist(),
+#                    'datetime': pd.Series(f_df.index.values).apply(lambda x:x.strftime('%Y-%m-%d')).tolist(),
+#                    'spread': f_df.spread.values.tolist(),
+#                    'spread_par': f_df.spread_par.values.tolist(),
+#                    'close': f_df.close.values.tolist(),
+#                    'index_quote': f_df[index_id].values.tolist()}
+            tag = f'    [spread]  em_id : {f_df.em_id.iloc[0]},days: {len(f_df)}'
+            return tag
+
     def process_future_price(self):
         try:
             # 期货数据
@@ -447,19 +518,30 @@ class DataChecker:
             trade_date_list = trade_date_list.datetime
 
             result = []
+            result_str = []
             for r in future_info.itertuples():
                 future_id = r.em_id
                 start_date = r.start_trade_date
                 end_date = r.deliver_date
+                contract_mul = r.contract_mul
                 close_i = close_price[[future_id]]
                 trade_date_i = trade_date_list[trade_date_list>=start_date].tolist()
                 df_i = close_i.reindex(trade_date_i)
                 lack_quote_date = df_i[df_i.isnull()[future_id].values].shape[0]
                 dic = {'future_id':future_id, 'name':r.desc_name, 'lack_quote_dates':lack_quote_date}
                 result.append(dic)
+                future_price_i = future_price[future_price.em_id == r.em_id]
+                pre_settlement_result = self._future_check_pre_settlement_price(future_price_i)
+                if pre_settlement_result:
+                    result_str.append(pre_settlement_result)
+                average_price = self._future_check_average_price(future_price_i, contract_mul)
+                if average_price:
+                    result_str.append(average_price)
+                # TODO check cfe data
+                # self._future_check_spread()          
 
             df = pd.DataFrame(result)
-            # 分批发送
+            # 分批发送 df
             bucket_size = int(df.shape[0] / max_size) + 1
             for i in range(bucket_size):
                 idx_b = i * max_size
@@ -475,6 +557,27 @@ class DataChecker:
                     }
                 }
                 res = requests.post(url=self.wechat_hook, data=json.dumps(message), timeout=20)
+            
+            # 分批发送 str
+            l = result_str
+            bucket_size = int(len(l) / max_size) + 1
+            for i in range(bucket_size):
+                idx_b = i * max_size
+                idx_e = min((i+1) * max_size, len(l))
+                res = f'[期货数据价量检查 部分数据] part {i+1} \r'
+                #print(idx_b,idx_e)
+                for s in l[idx_b:idx_e]:
+                    s = f'{s} /r'
+                    res += s
+                message = {
+                    'msgtype': 'markdown',
+                    'markdown': {
+                        'content': res
+                    }
+                }
+                res = requests.post(url=self.wechat_hook, data=json.dumps(message), timeout=20)
+            
+
         except Exception as e:
             print(f'Failed to get data <err_msg> {e} from DataChecker.process_future_price')
 
