@@ -651,15 +651,25 @@ class HedgeFundDataManager(metaclass=Singleton):
         assert math.isclose(nav_acc_data.net_asset_value.array[0], 1) and math.isclose(nav_acc_data.acc_unit_value.array[0], 1), f'fund nav data should start with 1 (data){nav_acc_data}'
 
         assert nav_acc_data.acc_unit_value.round(6).ge(nav_acc_data.net_asset_value.round(6)).all(), f'acc_unit_value should always ge than net_asset_value (data){nav_acc_data}'
-        days_before_dividend: pd.Series = (nav_acc_data.acc_unit_value - nav_acc_data.net_asset_value).round(6).drop_duplicates(keep='last')
+        # 公式一
+        # days_before_dividend: pd.Series = (nav_acc_data.acc_unit_value - nav_acc_data.net_asset_value).round(6).drop_duplicates(keep='last')
+        # 公式二
+        days_before_dividend: pd.Series = (nav_acc_data.acc_unit_value - nav_acc_data.net_asset_value).round(6).drop_duplicates(keep='first')
         assert days_before_dividend.notna().all(), f'fund nav data should not contains NaN (data){nav_acc_data}'
         # 这里算出来每天的分红数据不应该出现负值 这样前边的 drop_duplicates 才是对的
         assert days_before_dividend.is_monotonic_increasing, f'dividend should always be monotonic increasing (data){nav_acc_data}'
 
         divdidend_that_day: pd.Series = days_before_dividend.sub(days_before_dividend.shift(1, fill_value=0))
-        adj_factor: pd.Series = 1 + divdidend_that_day / (nav_acc_data.loc[divdidend_that_day.index, 'net_asset_value'].shift(1, fill_value=1) - divdidend_that_day)
+        # 公式一
+        # adj_factor: pd.Series = 1 + divdidend_that_day / (nav_acc_data.loc[divdidend_that_day.index, 'net_asset_value'].shift(1, fill_value=1) - divdidend_that_day)
+        # 公式二
+        net_asset_value = nav_acc_data.loc[divdidend_that_day.index, 'net_asset_value']
+        adj_factor: pd.Series = (net_asset_value + divdidend_that_day) / net_asset_value
 
-        df: pd.DataFrame = adj_factor.reindex(nav_acc_data.index, method='bfill').to_frame('adj_factor')
+        # 公式一
+        # df: pd.DataFrame = adj_factor.cumprod().reindex(nav_acc_data.index, method='bfill').to_frame('adj_factor')
+        # 公式二
+        df: pd.DataFrame = adj_factor.cumprod().reindex(nav_acc_data.index, method='ffill').to_frame('adj_factor')
         df['adj_nav'] = df.adj_factor * nav_acc_data.net_asset_value
         df['change_rate'] = df.adj_nav.pct_change()
         df = df[['adj_nav', 'adj_factor', 'change_rate']]
