@@ -990,4 +990,15 @@ class PfIndicatorWithBenchmark(Base):
     sortino = Column(DOUBLE(asdecimal=False)) # 索提诺
     skew = Column(DOUBLE(asdecimal=False)) # 偏度
     kurtosis = Column(DOUBLE(asdecimal=False)) # 峰度
-    total_relative_ret = Column(DOUBLE(asdecimal=False)) # 相对全部收益
\ No newline at end of file
+    total_relative_ret = Column(DOUBLE(asdecimal=False)) # 相对全部收益
+
+class FundTypeClassification(Base):
+    '''基金类型分类'''
+
+    __tablename__ = 'fund_type_classification'
+    
+    fund_type = Column(CHAR(10), primary_key=True) # 公募基金或者私募基金
+    fund_class_1_ori = Column(CHAR(10), primary_key=True) # 基金一级分类
+    fund_class_2_ori = Column(CHAR(40), primary_key=True) # 基金二级分类
+    fund_class_1 = Column(CHAR(10)) # 合并一级分类
+    fund_class_2 = Column(CHAR(40)) # 合并二级分类
\ No newline at end of file
