@@ -774,4 +774,72 @@ class HFFundDailyCollection(Base):
     annual_vol = Column(DOUBLE(asdecimal=False))  # 成立以来年化波动率
     sharpe_ratio = Column(DOUBLE(asdecimal=False))  # 成立以来夏普比率
     price_begin_date = Column(DATE)  # 净值开始时间
-    price_end_date = Column(DATE)  # 净值开始时间
\ No newline at end of file
+    price_end_date = Column(DATE)  # 净值开始时间
+
+class PFFundDailyCollection(Base):
+    """私募信息日度收集"""
+
+    __tablename__ = 'pf_fund_daily_collection'
+
+    fund_id = Column(CHAR(20), primary_key=True)  # 基金ID
+    desc_name = Column(CHAR(40)) # 基金名
+    datetime = Column(DATE) # 时间
+    fund_type_1 = Column(CHAR(40)) # 一级策略
+    fund_type_2 = Column(CHAR(40)) # 二级策略
+    # 收益
+    history_ret = Column(DOUBLE(asdecimal=False))  # 成立以来收益
+    history_ret_annual = Column(DOUBLE(asdecimal=False))  # 成立以来年化
+    recent_3m_ret_annual = Column(DOUBLE(asdecimal=False))  # 近3月年化
+    recent_6m_ret_annual = Column(DOUBLE(asdecimal=False))  # 近6月年年化
+    this_y_ret_annual = Column(DOUBLE(asdecimal=False))  # 今年年化
+    recent_2y_ret_annual = Column(DOUBLE(asdecimal=False))  # 近2年年化
+    this_y_ret = Column(DOUBLE(asdecimal=False))  # 今年以来收益
+    recent_3m_ret = Column(DOUBLE(asdecimal=False))  # 近3月年以来收益    
+    recent_6m_ret = Column(DOUBLE(asdecimal=False))  # 近6月以来收益
+    recent_1y_ret = Column(DOUBLE(asdecimal=False))  # 近1年以来收益    
+    recent_2y_ret = Column(DOUBLE(asdecimal=False))  # 近1年以来收益
+    # 风险
+    history_vol = Column(DOUBLE(asdecimal=False))  # 成立以来收益
+    history_mdd = Column(DOUBLE(asdecimal=False))  # 成立以来最大收益
+    this_y_mdd = Column(DOUBLE(asdecimal=False))   # 近年以来最大回撤
+    recent_3m_mdd = Column(DOUBLE(asdecimal=False))  # 近三个月最大回撤
+    recent_6m_mdd = Column(DOUBLE(asdecimal=False))  # 近六个月最大回撤
+    recent_1y_mdd = Column(DOUBLE(asdecimal=False))  # 近一年最大回撤
+    recent_2y_mdd = Column(DOUBLE(asdecimal=False))  # 近二年最大回撤
+    # 综合
+    sharpe = Column(DOUBLE(asdecimal=False))  # 夏普
+    calmar = Column(DOUBLE(asdecimal=False))  # 卡玛比率
+    sortino = Column(DOUBLE(asdecimal=False))  # 索提诺
+    var = Column(DOUBLE(asdecimal=False))  # VaR
+    
+    @staticmethod
+    def trans_columns():
+        return {
+            'fund_id':'基金ID',
+            'desc_name':'基金名',
+            'datetime':'时间',
+            'fund_type_1':'一级策略',
+            'fund_type_2':'二级策略',
+            'history_ret':'成立以来收益',
+            'history_ret_annual':'成立以来年化',
+            'recent_3m_ret_annual':'近3月年化',
+            'recent_6m_ret_annual':'抗风险能力',
+            'this_y_ret_annual':'今年年化',
+            'recent_2y_ret_annual':'近2年年化',
+            'this_y_ret':'今年以来收益',
+            'recent_3m_ret':'近3月年以来收益',   
+            'recent_6m_ret':'近6月以来收益',
+            'recent_1y_ret':'近1年以来收益',
+            'recent_2y_ret':'近1年以来收益',
+            'history_vol':'成立以来收益',
+            'history_mdd':'成立以来最大收益',
+            'this_y_mdd':'近年以来最大回撤',
+            'recent_3m_mdd':'近三个月最大回撤',
+            'recent_6m_mdd':'近六个月最大回撤',
+            'recent_1y_mdd':'近一年最大回撤',
+            'recent_2y_mdd':'近二年最大回撤',
+            'sharpe':'夏普',
+            'calmar':'卡玛比率',
+            'sortino':'索提诺',
+            'var':'VaR',
+        }
