@@ -158,22 +158,65 @@ class CalculatorBase:
             _res = {}
             for _period, _period_begin_date in begin_date_dic.items():
                 if _period_begin_date >= _begin_date and sr.index[-1] > _period_begin_date:
-                    _res[_period] = sr.loc[:last_date][-1] / sr.loc[_period_begin_date:][0] - 1
+                    b_d = sr.loc[_period_begin_date:].index[0]
+                    e_d = sr.loc[:last_date].index[-1]
+                    if e_d == b_d:
+                        _res[_period] = 0
+                        _res[f'{_period}_annual'] = 0
+                        _res[f'{_period}_mdd'] = 0
+                    else:
+                        sr_sub = sr.loc[b_d:e_d]
+                        days = (e_d - b_d).days
+                        last_unit_nav = sr_sub.iloc[-1] / sr_sub.iloc[0]
+                        _res[_period] = last_unit_nav - 1
+                        _res[f'{_period}_annual'] = math.pow(last_unit_nav, CalculatorBase.TOTAL_DAYS_PER_YEAR/days) - 1
+                        _res[f'{_period}_mdd'] = 1 - (sr_sub / sr_sub.cummax()).min()
+                    
                     if _period == 'w1':
                         _res['w1_begin_date'] = sr.loc[_period_begin_date:].index[0]
                         _res['w1_end_date'] = sr.loc[:last_date].index[-1]
                 else:
                     _res[_period] = np.nan
+                    _res[f'{_period}_annual'] = np.nan
+                    _res[f'{_period}_mdd'] = np.nan
+        
                     
             recent_1w_ret = _res['w1']
+            recent_1w_annual_ret = _res['w1_annual']
+            recent_1w_mdd = _res['w1_mdd']
+
             recent_1m_ret = _res['m1']
+            recent_1m_annual_ret = _res['m1_annual']
+            recent_1m_mdd = _res['m1_mdd']
+            
             recent_3m_ret = _res['m3']
+            recent_3m_annual_ret = _res['m3_annual']
+            recent_3m_mdd = _res['m3_mdd']
+
             recent_6m_ret = _res['m6']
+            recent_6m_annual_ret = _res['m6_annual']
+            recent_6m_mdd = _res['m6_mdd']
+            
             recent_1y_ret = _res['y1']
+            recent_1y_annual_ret = _res['y1_annual']
+            recent_1y_mdd = _res['y1_mdd']
+
             recent_2y_ret = _res['y2']
+            recent_2y_annual_ret = _res['y2_annual']
+            recent_2y_mdd = _res['y2_mdd']
+
             recent_3y_ret = _res['y3']
+            recent_3y_annual_ret = _res['y3_annual']
+            recent_3y_mdd = _res['y3_mdd']
+
             recent_4y_ret = _res['y4']
+            recent_4y_annual_ret = _res['y4_annual']
+            recent_4y_mdd = _res['y4_mdd']
+
             recent_5y_ret = _res['y5']
+            recent_5y_annual_ret = _res['y5_annual']
+            recent_5y_mdd = _res['y5_mdd']
+
             if 'w1_begin_date' in _res:
                 w1_begin_date = _res['w1_begin_date']
                 w1_end_date = _res['w1_end_date']
@@ -202,7 +245,15 @@ class CalculatorBase:
             date_last_b = max(sr.index.min(),_date_last_b)
             date_last_e = min(sr.index.max(),_date_last_e)
             _sr = sr[date_last_b:date_last_e]
-            y_last_ret = _sr[-1] / _sr[0] - 1 if not _sr.empty else None
+            if not _sr.empty:
+                y_last_ret = _sr[-1] / _sr[0] - 1 
+                y_last_ret_annual = math.pow(_sr[-1] / _sr[0], CalculatorBase.TOTAL_DAYS_PER_YEAR/(date_last_e-date_last_b).days) - 1
+                y_last_mdd = 1 - (_sr / _sr.cummax()).min()
+            else:
+                y_last_ret = None
+                y_last_ret_annual = None
+                y_last_mdd = None
+
             return {
                 'recent_natural_year_ret':recent_natural_year_ret,
                 'recent_1w_ret':recent_1w_ret,
@@ -221,6 +272,26 @@ class CalculatorBase:
                 'last_year_ret':y_last_ret,
                 'w1_begin_date':w1_begin_date,
                 'w1_end_date':w1_end_date,
+                'recent_1w_annual_ret':recent_1w_annual_ret,
+                'recent_1w_mdd':recent_1w_mdd,
+                'recent_1m_annual_ret':recent_1m_annual_ret,
+                'recent_1m_mdd':recent_1m_mdd,
+                'recent_3m_annual_ret':recent_3m_annual_ret,
+                'recent_3m_mdd':recent_3m_mdd,
+                'recent_6m_annual_ret':recent_6m_annual_ret,
+                'recent_6m_mdd':recent_6m_mdd,
+                'recent_1y_annual_ret':recent_1y_annual_ret,
+                'recent_1y_mdd':recent_1y_mdd,
+                'recent_2y_annual_ret':recent_2y_annual_ret,
+                'recent_2y_mdd':recent_2y_mdd,
+                'recent_3y_annual_ret':recent_3y_annual_ret,
+                'recent_3y_mdd':recent_3y_mdd,
+                'recent_4y_annual_ret':recent_4y_annual_ret,
+                'recent_4y_mdd':recent_4y_mdd,
+                'recent_5y_annual_ret':recent_5y_annual_ret,
+                'recent_5y_mdd':recent_5y_mdd,
+                'y_last_ret_annual':y_last_ret_annual,
+                'y_last_mdd':y_last_mdd,
             }
         
         except Exception as e:
@@ -243,6 +314,26 @@ class CalculatorBase:
                 'last_year_ret':0,
                 'w1_begin_date':None,
                 'w1_end_date':None,
+                'recent_1w_annual_ret':0,
+                'recent_1w_mdd':0,
+                'recent_1m_annual_ret':0,
+                'recent_1m_mdd':0,
+                'recent_3m_annual_ret':0,
+                'recent_3m_mdd':0,
+                'recent_6m_annual_ret':0,
+                'recent_6m_mdd':0,
+                'recent_1y_annual_ret':0,
+                'recent_1y_mdd':0,
+                'recent_2y_annual_ret':0,
+                'recent_2y_mdd':0,
+                'recent_3y_annual_ret':0,
+                'recent_3y_mdd':0,
+                'recent_4y_annual_ret':0,
+                'recent_4y_mdd':0,
+                'recent_5y_annual_ret':0,
+                'recent_5y_mdd':0,
+                'y_last_ret_annual':0,
+                'y_last_mdd':0,
             }
 
     @staticmethod
@@ -475,6 +566,28 @@ class CalculatorBase:
             recent_4w_ret = recent_ret_res['recent_4w_ret']
             last_year_ret = recent_ret_res['last_year_ret']
             w1_begin_date = recent_ret_res['w1_begin_date']
+            recent_2y_ret = recent_ret_res['recent_2y_ret']
+            recent_1w_annual_ret = recent_ret_res['recent_1w_annual_ret']
+            recent_1w_mdd = recent_ret_res['recent_1w_mdd']
+            recent_1m_annual_ret = recent_ret_res['recent_1m_annual_ret']
+            recent_1m_mdd = recent_ret_res['recent_1m_mdd']
+            recent_3m_annual_ret = recent_ret_res['recent_3m_annual_ret']
+            recent_3m_mdd = recent_ret_res['recent_3m_mdd']
+            recent_6m_annual_ret = recent_ret_res['recent_6m_annual_ret']
+            recent_6m_mdd = recent_ret_res['recent_6m_mdd']
+            recent_1y_annual_ret = recent_ret_res['recent_1y_annual_ret']
+            recent_1y_mdd = recent_ret_res['recent_1y_mdd']
+            recent_2y_annual_ret = recent_ret_res['recent_2y_annual_ret']
+            recent_2y_mdd = recent_ret_res['recent_2y_mdd']
+            recent_3y_annual_ret = recent_ret_res['recent_3y_annual_ret']
+            recent_3y_mdd = recent_ret_res['recent_3y_mdd']
+            recent_4y_annual_ret = recent_ret_res['recent_4y_annual_ret']
+            recent_4y_mdd = recent_ret_res['recent_4y_mdd']
+            recent_5y_annual_ret = recent_ret_res['recent_5y_annual_ret']
+            recent_5y_mdd = recent_ret_res['recent_5y_mdd']
+            y_last_ret_annual = recent_ret_res['y_last_ret_annual']
+            y_last_mdd = recent_ret_res['y_last_mdd']
+
             w1_end_date = recent_ret_res['w1_end_date']
             y_2020_ret = recent_ret_res['y_2020_ret']
             worst_3m_ret = sr.pct_change(period_3m).min()
@@ -550,7 +663,9 @@ class CalculatorBase:
                 sr_benchmark_ret_weekly = CalculatorBase.data_resample_weekly_ret(df=sr_benchmark_ret, min_count=1).dropna()
                 sr_benchmark_ret_monthly = CalculatorBase.data_resample_monthly_ret(df=sr_benchmark_ret, min_count=1).dropna()
                 
-                
+                _sr_benchmark = sr_benchmark.loc[mdd_date1:mdd_date2]
+                mdd_benchmark_same_time = 1 - (_sr_benchmark / _sr_benchmark.cummax()).min()
+                asset_to_bmk_mdd = mdd / mdd_benchmark_same_time
                 win_rate = np.mean((sr_ret > sr_benchmark_ret) * 1)
                 win_rate_0 = np.mean((sr_ret > 0) * 1)
                 win_rate_weekly = np.mean((sr_ret_weekly > sr_benchmark_ret_weekly) * 1)
@@ -690,6 +805,28 @@ class CalculatorBase:
                     'nav_type':nav_type,
                     'w1_begin_date':w1_begin_date,
                     'w1_end_date':w1_end_date,
+                    'asset_to_bmk_mdd':asset_to_bmk_mdd,
+                    'recent_2y_ret':recent_2y_ret,
+                    'recent_1w_annual_ret':recent_1w_annual_ret,
+                    'recent_1w_mdd':recent_1w_mdd,
+                    'recent_1m_annual_ret':recent_1m_annual_ret,
+                    'recent_1m_mdd':recent_1m_mdd,
+                    'recent_3m_annual_ret':recent_3m_annual_ret,
+                    'recent_3m_mdd':recent_3m_mdd,
+                    'recent_6m_annual_ret':recent_6m_annual_ret,
+                    'recent_6m_mdd':recent_6m_mdd,
+                    'recent_1y_annual_ret':recent_1y_annual_ret,
+                    'recent_1y_mdd':recent_1y_mdd,
+                    'recent_2y_annual_ret':recent_2y_annual_ret,
+                    'recent_2y_mdd':recent_2y_mdd,
+                    'recent_3y_annual_ret':recent_3y_annual_ret,
+                    'recent_3y_mdd':recent_3y_mdd,
+                    'recent_4y_annual_ret':recent_4y_annual_ret,
+                    'recent_4y_mdd':recent_4y_mdd,
+                    'recent_5y_annual_ret':recent_5y_annual_ret,
+                    'recent_5y_mdd':recent_5y_mdd,
+                    'y_last_ret_annual':y_last_ret_annual,
+                    'y_last_mdd':y_last_mdd,
                 }
             else:
                 return {
@@ -742,6 +879,27 @@ class CalculatorBase:
                     'nav_type':nav_type,
                     'w1_begin_date':w1_begin_date,
                     'w1_end_date':w1_end_date,
+                    'recent_2y_ret':recent_2y_ret,
+                    'recent_1w_annual_ret':recent_1w_annual_ret,
+                    'recent_1w_mdd':recent_1w_mdd,
+                    'recent_1m_annual_ret':recent_1m_annual_ret,
+                    'recent_1m_mdd':recent_1m_mdd,
+                    'recent_3m_annual_ret':recent_3m_annual_ret,
+                    'recent_3m_mdd':recent_3m_mdd,
+                    'recent_6m_annual_ret':recent_6m_annual_ret,
+                    'recent_6m_mdd':recent_6m_mdd,
+                    'recent_1y_annual_ret':recent_1y_annual_ret,
+                    'recent_1y_mdd':recent_1y_mdd,
+                    'recent_2y_annual_ret':recent_2y_annual_ret,
+                    'recent_2y_mdd':recent_2y_mdd,
+                    'recent_3y_annual_ret':recent_3y_annual_ret,
+                    'recent_3y_mdd':recent_3y_mdd,
+                    'recent_4y_annual_ret':recent_4y_annual_ret,
+                    'recent_4y_mdd':recent_4y_mdd,
+                    'recent_5y_annual_ret':recent_5y_annual_ret,
+                    'recent_5y_mdd':recent_5y_mdd,
+                    'y_last_ret_annual':y_last_ret_annual,
+                    'y_last_mdd':y_last_mdd,
                 }
         else:
             return {
@@ -826,6 +984,28 @@ class CalculatorBase:
                     'nav_type':'nan',
                     'w1_begin_date':dates[0] if len(dates) > 0 else None,
                     'w1_end_date':dates[0] if len(dates) > 0 else None,
+                    'recent_2y_ret':0,
+                    'recent_1w_annual_ret':0,
+                    'recent_1w_mdd':0,
+                    'recent_1m_annual_ret':0,
+                    'recent_1m_mdd':0,
+                    'recent_3m_annual_ret':0,
+                    'recent_3m_mdd':0,
+                    'recent_6m_annual_ret':0,
+                    'recent_6m_mdd':0,
+                    'recent_1y_annual_ret':0,
+                    'recent_1y_mdd':0,
+                    'recent_2y_annual_ret':0,
+                    'recent_2y_mdd':0,
+                    'recent_3y_annual_ret':0,
+                    'recent_3y_mdd':0,
+                    'recent_4y_annual_ret':0,
+                    'recent_4y_mdd':0,
+                    'recent_5y_annual_ret':0,
+                    'recent_5y_mdd':0,
+                    'y_last_ret_annual':0,
+                    'y_last_mdd':0,
+                    'asset_to_bmk_mdd':0,
                 }
 
 
@@ -1076,7 +1256,7 @@ class CalculatorBase:
         if sr.dropna().shape[0] > 0 and nav_density_monthy == 0:
             sr = pd.Series(values, index=dates).sort_index()
             sr_week = CalculatorBase.data_resample_weekly_nav(df=sr)
-            sr_week = sr.reindex(dts.index)
+            sr_week = sr.reindex(dts)
             sr_week = CalculatorBase.data_resample_weekly_nav(df=sr)
             sr_month = CalculatorBase.data_resample_monthly_nav(df=sr_week)
             nav_density_weeky = 1 - (sum(sr_week.isnull() * 1) / sr_week.shape[0])
